@@ -7,7 +7,6 @@ from classy_imaginary.api import _generate_single_image
 from classy_imaginary import ImaginePrompt, ImagineResult
 from classy_imaginary.enhancers.face_restoration_codeformer import codeformer_model
 from classy_imaginary.model_manager import get_diffusion_model
-from classy_imaginary.modules.midas.utils import AddMiDaS
 from classy_imaginary.safety import EnhancedStableDiffusionSafetyChecker
 from classy_imaginary.utils import platform_appropriate_autocast, fix_torch_nn_layer_norm, fix_torch_group_norm
 from transformers import logging as transformers_logging, AutoFeatureExtractor
@@ -51,11 +50,6 @@ class Imagine:
             for_inpainting=for_inpainting,
         )
 
-        if for_inpainting:
-            self.midas_model = AddMiDaS()
-        else:
-            self.midas_model = None
-
         safety_model_id = "CompVis/stable-diffusion-safety-checker"
         self.safety_feature_extractor = AutoFeatureExtractor.from_pretrained(safety_model_id)
         self.safety_checker = EnhancedStableDiffusionSafetyChecker.from_pretrained(
@@ -86,7 +80,6 @@ class Imagine:
             result = _generate_single_image(
                 prompt,
                 self.sd_model,
-                midas_model=self.midas_model,
                 nsfw_filter=nsfw_filter,
                 safety_feature_extractor=self.safety_feature_extractor,
                 safety_checker=self.safety_checker,
@@ -95,7 +88,6 @@ class Imagine:
                 progress_img_callback=progress_img_callback,
                 progress_img_interval_steps=progress_img_interval_steps,
                 progress_img_interval_min_s=progress_img_interval_min_s,
-                half_mode=self.half_mode,
                 add_caption=False,
             )
 
