@@ -11,6 +11,8 @@ from torch.nn.functional import silu
 
 from classy_imaginary.modules.attention import MemoryEfficientCrossAttention
 from classy_imaginary.utils import get_device
+import logging.config
+logger = logging.getLogger(__name__)
 
 XFORMERS_IS_AVAILABLE = False
 
@@ -20,7 +22,9 @@ try:
         import xformers.ops  # noqa
 
         XFORMERS_IS_AVAILABLE = True
+        logger.info("xformers is available")
 except ImportError:
+    logger.info("xformers is not available")
     pass
 
 
